@@ -1,12 +1,13 @@
 ;;; no-littering.el --- Help keeping ~/.config/emacs clean  -*- lexical-binding:t -*-
 
-;; Copyright (C) 2016-2023 Jonas Bernoulli
+;; Copyright (C) 2016-2024 Jonas Bernoulli
 
-;; Author: Jonas Bernoulli <jonas@bernoul.li>
+;; Author: Jonas Bernoulli <emacs.no-littering@jonas.bernoulli.dev>
 ;; Homepage: https://github.com/emacscollective/no-littering
 ;; Keywords: convenience
 
-;; Package-Requires: ((emacs "25.1") (compat "29.1.4.1"))
+;; Package-Version: 1.7.1
+;; Package-Requires: ((emacs "26.1") (compat "30.0.0.0"))
 
 ;; SPDX-License-Identifier: GPL-3.0-or-later
 
@@ -74,108 +75,12 @@
 ;;         (expand-file-name "data/" user-emacs-directory))
 ;;   (require 'no-littering)
 
-;; For additional optional settings see "README.md".
+;; For additional optional settings see "README.org".
 
 ;;;; Conventions
-;;;;; A) File names
-;;
-;; 1. File names are based on the name of the respective Emacs Lisp
-;;    variables and the name of the respective Emacs package.
-;;
-;; 2. The name of the respective Emacs package should serve as the
-;;    prefix of the file name, unless the file is in a subdirectory in
-;;    which case the name of the subdirectory serves as the prefix.
-;;
-;; 3. If the name of the package and the prefix of the variable do not
-;;    match, then we prefer the name of the package.
-;;
-;; 4. If the name of a path variable ends with `-file`, `-default-file`,
-;;    `-directory`, `-default-directory`, or something similar, then that
-;;    suffix is usually dropped from the file name.
-;;
-;; 5. If applicable, the appropriate extension is added to the file name
-;;    so that files are visited using the appropriate major-modes and
-;;    also to provide a hint about the kind of data stored in the file.
-;;    E.g.,  if a file contains an S-expression, then the suffix should
-;;    be `*.el`.
 
-;;;;; B) File location and subdirectories
-;;
-;; 1. If a package has only one data file, then that is usually placed in
-;;    `no-littering-var-directory` itself.  Likewise if a package has
-;;    only one config file, then that is placed in
-;;    `no-littering-etc-directory` itself.
-;;
-;; 2. If a package has multiple data (or config files), then those files
-;;    are placed in a subdirectory of `no-littering-var-directory` (or
-;;    `no-littering-etc-directory`).
-;;
-;; 3. If a subdirectory is used for a package's data (or config) file
-;;    variables, then the name of the directory should match the name of
-;;    the package in most cases.  The subdirectory name may serve as the
-;;    package prefix of the file name.
-;;
-;; 4. If a package provides a "framework" for other packages to use,
-;;    then we may reuse its directories for other packages that make use
-;;    of that framework or otherwise "extend" the "main package".
-;;    E.g., we place all `helm` related files in `helm/`.
-;;
-;; 5. If a package only defines a single variable that specifies a data
-;;    (or config) directory, then the directory name should
-;;    nevertheless be just the package name.  E.g., the path used for
-;;    `sx-cache-directory` from the `sx` package is `sx/cache/`, not
-;;    `sx-cache/`.
-;;
-;; 6. However if the name of the directory variable implies that the
-;;    package won't ever define any data (or config) files that won't be
-;;    placed in that directory, then we use a top-level directory.  E.g.
-;;    when the name of the variable is `<package>-directory`, in which
-;;    case we would use just `<package>/` as the path.
-
-;;;;; C) Ordering and alignment
-;;
-;; 1. The code that sets the values of themed variables is split into two
-;;    groups.  The first group sets the value of variables that belong to
-;;    packages that are part of Emacs, and the second group is used for
-;;    variables that are defined by packages that are not part of Emacs.
-;;
-;; 2. Each of these lists is sorted alphabetically (usually by variable
-;;    name).  Please keep it that way.
-;;
-;; 3. We attempt to align the value forms inside different `setq` forms.
-;;    If the symbol part for a particular variable is too long to allow
-;;    doing so, then don't worry about it and just break the alignment.
-;;    If it turns out that this happens very often, then we will adjust
-;;    the alignment eventually.
-
-;;;;; D) Commit messages
-;;
-;; 1. Please theme each package using a separate commit and use commit
-;;    messages of the form "<package>: Theme <variable".
-;;
-;; 2. If a package has several path variables, then you should theme them
-;;    all in one commit.
-;;
-;; 3. If the variable names do not fit nicely on the summary line, then
-;;    use a message such as:
-;;
-;;      foo: Theme variables
-;;
-;;      Theme `foo-config-file', `foo-cache-directory',
-;;      and `foo-persistent-file'.
-;;
-;; 4. When appropriate add statements like the following to the commit
-;;    message:
-;;
-;;    - This file is used to store an s-expression.
-;;    - This file is used to store raw text.
-;;    - This is the only configuration/data file of the package.
-;;    - This package does/doesn't take care of creating the containing
-;;      directory if necessary. (If the package does not do it, then you
-;;      should also fix that and submit an upstream pull request.)
-;;
-;; 5. If you are uncertain, then be explicit about it by adding a comment
-;;    to the pull-request.
+;; Please see the "README.org" file in this repository or the exported
+;; version at https://emacsmirror.net/manual/no-littering.html.
 
 ;;; Code:
 
@@ -226,6 +131,7 @@ This variable has to be set before `no-littering' is loaded.")
     (setq ede-project-placeholder-cache-file (var "ede-projects.el"))
     (setq erc-dcc-get-default-directory    (var "erc/dcc/"))
     (setq erc-log-channels-directory       (var "erc/log-channels/"))
+    (setq erc-startup-file-list            (list (etc "erc/startup.el") (etc "erc/startup") ".ercrc.el" ".ercrc"))
     (setq eshell-aliases-file              (etc "eshell/aliases"))
     (setq eshell-directory-name            (var "eshell/"))
     (setq eshell-login-script              (etc "eshell/login"))
@@ -239,11 +145,13 @@ This variable has to be set before `no-littering' is loaded.")
     ;; Gnus hardcodes newsrc.eld to be based on gnus-startup-file.
     (setq gnus-startup-file                (etc "gnus/newsrc"))
     (setq ido-save-directory-list-file     (var "ido-save-directory-list.el"))
+    (setq ielm-history-file-name           (var "ielm-history.eld"))
     (setq image-dired-db-file              (var "image-dired/db.el"))
     (setq image-dired-dir                  (var "image-dired/"))
     (setq image-dired-gallery-dir          (var "image-dired/gallery/"))
     (setq image-dired-temp-image-file      (var "image-dired/temp-image"))
     (setq image-dired-temp-rotate-image-file (var "image-dired/temp-rotate-image"))
+    (setq Info-saved-history-file          (var "info-saved-history.eld"))
     (setq kkc-init-file-name               (var "kkc-init.el"))
     (setq multisession-directory           (var "multisession/"))
     (setq newsticker-cache-filename        (var "newsticker/cache.el"))
@@ -253,6 +161,7 @@ This variable has to be set before `no-littering' is loaded.")
     (setq org-id-locations-file            (var "org/id-locations.el"))
     (setq org-persist-directory            (var "org/persist/"))
     (setq org-publish-timestamp-directory  (var "org/timestamps/"))
+    (setq persist--directory-location      (var "persist/"))
     (setq project-list-file                (var "project-list.el"))
     (setq quickurl-url-file                (var "quickurl-url.el"))
     (setq rcirc-log-directory              (var "rcirc-log/"))
@@ -296,6 +205,8 @@ This variable has to be set before `no-littering' is loaded.")
     (setq auto-package-update-last-update-day-path (var "auto-package-update-last-update-day"))
     (setq bbdb-file                        (var "bbdb/bbdb.el"))
     (setq bbdb-vcard-directory             (var "bbdb/vcard/"))
+    (setq binky-cache-directory            (var "binky/cache/"))
+    (setq blamer-avatar-folder             (var "blamer/avatars/"))
     (setq bm-repository-file               (var "bm-repository.el"))
     (setq bmkp-bmenu-commands-file         (var "bmkp/bmenu-commands.el"))
     (setq bmkp-current-bookmark-file       (var "bmkp/current-bookmark.el"))
@@ -309,9 +220,11 @@ This variable has to be set before `no-littering' is loaded.")
     (setq company-statistics-file          (var "company/statistics.el"))
     (setq company-tabnine-binaries-folder  (var "company/tabnine-binaries"))
     (setq conventional-changelog-tmp-dir   (var "conventional-changelog/"))
+    (setq copilot-install-dir              (var "copilot/"))
     (setq dap-breakpoints-file             (var "dap/breakpoints.el"))
     (setq dap-java-test-runner             (var "lsp-java/eclipse.jdt.ls/test-runner/junit-platform-console-standalone.jar"))
     (setq dap-utils-extension-path         (var "dap/extensions/"))
+    (setq dape-adapter-dir                 (var "dape-adapters/"))
     (setq debbugs-gnu-persistency-file     (var "debbugs.el"))
     (setq detached-db-directory            (var "detached/db/"))
     (setq detached-session-directory       (var "detached/sessions/"))
@@ -319,10 +232,12 @@ This variable has to be set before `no-littering' is loaded.")
     (setq devdocs-data-dir                 (var "devdocs/data/"))
     (setq dired-recent-directories-file    (var "dired-recent-directories.el"))
     (setq dirvish-cache-dir                (var "dirvish/cache"))
+    (setq efar-state-file-name             (var "efar-state.eld"))
     (setq elbank-data-file                 (var "elbank-data.el"))
     (setq elfeed-autotag-files             (list (etc "elfeed/autotags.org")))
     (setq elfeed-db-directory              (var "elfeed/db/"))
     (setq elfeed-enclosure-default-dir     (var "elfeed/enclosures/"))
+    (setq elfeed-score-rule-stats-file     (var "elfeed/score/score-rule-stats.eld"))
     (setq elfeed-score-score-file          (etc "elfeed/score/score.el"))
     (setq elgrep-data-file                 (var "elgrep-data.el"))
     (setq elisp-autofmt-cache-directory    (var "elisp-autofmt/cache/"))
@@ -342,6 +257,7 @@ This variable has to be set before `no-littering' is loaded.")
     (setq geiser-repl-history-filename     (var "geiser/repl-history"))
     (setq gnus-notes-file                  (var "gnus-notes/articles.el"))
     (setq gnus-notes-top-dir               (var "gnus-notes/"))
+    (setq gptel-crowdsourced-prompts-file  (var "gptel-crowdsourced-prompts.csv"))
     (setq grammalecte-settings-file        (etc "grammalecte-settings.el"))
     (setq hackernews-visited-links-file    (var "hackernews/visited-links.el"))
     (setq harpoon-cache-file               (var "harpoon/"))
@@ -358,6 +274,7 @@ This variable has to be set before `no-littering' is loaded.")
     (setq keyfreq-file                     (var "keyfreq.el"))
     (setq keyfreq-file-lock                (var "keyfreq.lock"))
     (setq libbcel-oauth-store-filename     (var "libbcel-oauth-store.el.gpg"))
+    (setq linkmarks-file                   (var "linkmarks.org"))
     (setq litable-list-file                (var "litable-list.el"))
     (setq logview-cache-filename           (var "logview-cache"))
     (setq logview-views-file               (etc "logview-views"))
@@ -372,6 +289,7 @@ This variable has to be set before `no-littering' is loaded.")
     (setq lsp-session-file                 (var "lsp/session.el"))
     (setq magithub-cache-file              (var "magithub/cache.el"))
     (setq magithub-dir                     (var "magithub/"))
+    (setq mastodon-client--token-file      (var "mastodon-client--token"))
     (setq mc/list-file                     (var "mc-list.el"))
     (setq meghanada-server-install-dir     (var "meghanada/"))
     (setq multi-compile-history-file       (var "multi-compile-history.el"))
@@ -405,6 +323,7 @@ This variable has to be set before `no-littering' is loaded.")
     (setq purpose-layout-dirs              (list (etc "window-purpose/layouts/")))
     (setq pyim-dcache-directory            (var "pyim/dcache/"))
     (setq quack-dir                        (var "quack/"))
+    (setq racket-repl-command-file         (etc "racket-mode/repl.rkt"))
     (setq racket-repl-history-directory    (var "racket-mode/repl-history/"))
     (setq request-storage-directory        (var "request/storage/"))
     (setq rfc-mode-directory               (var "rfc-mode/"))
@@ -422,6 +341,7 @@ This variable has to be set before `no-littering' is loaded.")
     (setq svg-lib-icons-dir                (var "svg-lib/icons/"))
     (setq sx-cache-directory               (var "sx/cache/"))
     (setq tabspaces-session-file           (var "tabspaces-session.eld"))
+    (setq tempel-path                      (etc "tempel/templates.eld"))
     (setq tldr-directory-path              (var "tldr/"))
     (setq transient-history-file           (var "transient/history.el"))
     (setq transient-levels-file            (etc "transient/levels.el"))
@@ -447,6 +367,7 @@ This variable has to be set before `no-littering' is loaded.")
     (eval-after-load 'bookmark+-1 `(make-directory ,(var "bmkp/") t))
     (eval-after-load 'command-log-mode '(make-directory clm/logging-dir t))
     (eval-after-load 'company     `(make-directory ,(var "company/") t))
+    (eval-after-load 'dape        '(make-directory dape-adapter-dir t))
     (eval-after-load 'elfeed      `(make-directory ,(var "elfeed/") t))
     (eval-after-load 'emojify     '(make-directory emojify-emojis-dir t))
     (eval-after-load 'geiser      `(make-directory ,(var "geiser/") t))
@@ -466,20 +387,18 @@ This variable has to be set before `no-littering' is loaded.")
 
 ;;; Advices
 
-(defun no-littering-emacs-session-filename (session-id)
+(define-advice emacs-session-filename (:override (session-id) no-littering)
   "Construct a filename to save the session in, based on SESSION-ID.
 Unconditionally return a filename in `no-littering-var-directory'."
   (let ((dir (no-littering-expand-var-file-name "emacs-session/")))
     (make-directory dir t)
     (expand-file-name session-id dir)))
 
-(advice-add 'emacs-session-filename :override
-            #'no-littering-emacs-session-filename)
-
 ;;; Backups
 
 (defvar undo-tree-history-directory-alist)
 
+;;;###autoload
 (defun no-littering-theme-backups ()
   "Theme locations where backups of various sorts are created.
 
